# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module.

Define class for information about backup, data copy and so on.
"""


class IgnoreInfo(object):
    """Class for ignored folder/file."""

    BEGIN = "begin"
    END = "end"
    CONTAIN = "contain"
    EXACT = "exact"

    def __init__(self, ignore_type, pattern):
        """Constructer."""

        self.type = ignore_type
        self.pattern = pattern.lower()

    def match(self, pattern):
        """Check if "pattern" should be ignored."""

        if self.type == self.BEGIN:
            return pattern.lower().startswith(self.pattern)

        if self.type == self.END:
            return pattern.lower().endswith(self.pattern)

        if self.type == self.CONTAIN:
            if pattern.lower().find(self.pattern) >= 0:
                return True
            return False

        if self.type == self.EXACT:
            if pattern.lower() == self.pattern:
                return True
            return False

        return False


class JobInfo(object):
    """Base class for job information about backup, data copy and so on."""

    def __init__(self, name):
        """Constructor."""

        self.name = name
        self.ignore_info_list = []

    def add_ignore_info(self, ignore_type, pattern):
        """Add new IgnoreInfo instance."""

        self.ignore_info_list.append(IgnoreInfo(ignore_type, pattern))


class ConnectionInfo(object):
    """Base class for connection information."""

    def __init__(self, name):
        """Constructor."""

        self.name = name


class TargetInfo(object):
    """Base class for target information."""

    def __init__(self, type, connection_info):
        """Constructor."""

        self.type = type
        self.connection_info = connection_info
