# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""File Access module.

Define base classes for file access.
"""


class FileObj(object):
    """Base class for file."""

    def __init__(self):
        """Constructor."""

        pass

    def close(self):
        """Close file."""

        # Default Do nothing
        pass

    def read(self, size=-1):
        """Return a "size" bytes data from current position in file.
        If the size argument is negative or omitted, then return all data.
        """

        raise NotImplementedError

    def write(self, data):
        """Write a "data" data to current position in file."""

        raise NotImplementedError


class Access(object):
    """Base class accessing to file."""

    def __init__(self):
        """Constructor."""

        pass

    @property
    def max_num_transfer_threads(self):
        """Return maximum thread number for file transfer."""

        return 1

    def convert_name(self, name):
        """Converting "name" for target platform."""

        return name

    def compare_name(self, one, other):
        """Compare string "one" and "other"."""

        return one == other

    def make_directory(self, dir_path):
        """Create "dir_path" directory."""

        raise NotImplementedError

    def delete_directory(self, dir_path):
        """Delete "dir_path" directory."""

        raise NotImplementedError

    def stat_directory(self, dir_path):
        """Return a stat information dictionary for "dir_path"
           which keys below:
            stat.ST_MODE, stat.ST_MTIME, stat.CTIME, stat.ST_SIZE
        """

        raise NotImplementedError

    def rename_directory(self, dir_path, new_name):
        """Rename a name of "dir_path" to "new_name"."""

        raise NotImplementedError

    def move_directory(self, dir_path, new_dir_path):
        """Move "dir_path" to "new_path"."""

        raise NotImplementedError

    def get_contents(self, dir_path, with_stat=False):
        """Return a contents dictionary in "dir_path".
           A stat information must be included, if "with_stat" is True, 
        """

        raise NotImplementedError

    def get_updated_contents(self, dir_path):
        """Return a updated contents dictionary in "dir_path"."""

        raise NotImplementedError

    def open(self, file_path, mode="r"):
        """Return a class instance of the "FileObj" or sub class
           corresponding to "file_path".
        """

        raise NotImplementedError

    def delete_file(self, file_path):
        """Delete "file_path" file."""

        raise NotImplementedError

    def stat_file(self, file_path):
        """Return a stat information dictionary for "file_path"
           which keys below:
            stat.ST_MODE, stat.ST_MTIME, stat.CTIME, stat.ST_SIZE
        """

        raise NotImplementedError

    def rename_file(self, file_path, new_name):
        """Rename a name of "file_path" to "new_name"."""

        raise NotImplementedError

    def move_file(self, file_path, new_dir_path):
        """Move "file_path" to "new_path"."""

        raise NotImplementedError
