# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module for Amazon S3.

Define class for information about backup, data copy and so on.
"""


from iobase.xmldata import (XmlNode)
from ionas.backupsync.info import (ConnectionInfo, TargetInfo,)

from boto.s3.connection import (S3Connection,)

#from pkgaddon.amazons3_config import (HOST_NAME_KEY,
#                                            USING_IMAGE_LOGIN_KEY,
#                                            COMPANY_ID_KEY,
#                                            SERVICE_ID_KEY,
#                                            DESTINATION_INFO_MAP)


NAME_NAME = "name"
ID_NAME = "id"
ACCESSKEY_NAME = "accesskey"
SECRETKEY_NAME = "secretkey"
HTTPMETHOD_NAME = "httpmethod"
STORAGECLASS_NAME = "storageclass"
ENDPOINT_NAME = "endpoint"
PORT_NAME = "port"
MPUPLOAD_NAME = "mpupload"

TYPE_NAME = "type"
BUCKET_NAME = "bucket"
SUBDIR_NAME = "subdir"

class AmazonS3ConnectionInfo(ConnectionInfo):
    """Class for Amazon S3 connection information."""

    def __init__(self, connection_xml):
        """Constructor."""

        super(AmazonS3ConnectionInfo, self).__init__(
                                    connection_xml.get_value(NAME_NAME))

        self.id = connection_xml.get_value(ID_NAME, "")
        self.accesskey = connection_xml.get_value(ACCESSKEY_NAME, "")
        self.secretkey = connection_xml.get_value(SECRETKEY_NAME, "")
        self.httpmethod = connection_xml.get_value(HTTPMETHOD_NAME, "")
        self.storageclass = connection_xml.get_value(STORAGECLASS_NAME, "")
        self.endpoint = connection_xml.get_value(ENDPOINT_NAME,
                            S3Connection.DefaultHost)
        if not self.endpoint:
            self.endpoint = S3Connection.DefaultHost
        self.port = connection_xml.get_value(PORT_NAME, "")
        try:
            self.use_mpupload = \
                    connection_xml.get_node(MPUPLOAD_NAME).is_enabled()
        except:
            self.use_mpupload = False


class AmazonS3TargetInfo(TargetInfo):
    """Class for Amazon S3 target information."""

    def __init__(self, target_xml, connection_xml):
        """Constructor."""

        super(AmazonS3TargetInfo, self).__init__(
                                target_xml.get_value(TYPE_NAME),
                                AmazonS3ConnectionInfo(connection_xml))

        self.bucket = target_xml.get_value(BUCKET_NAME, "")
        self.subdir = target_xml.get_value(SUBDIR_NAME, "")

    def get_root_path(self):
        return u"/"

    def get_target_name(self):
        target_name = "amazons3_" + self.connection_info.name
        if isinstance(target_name, str):
            target_name = target_name.decode("UTF8")

        return target_name

    def do_wait_modified(self):
        return False
